@@ -1,7 +1,7 @@
 --
 -- HTTP client for use with io-streams
 --
--- Copyright © 2012-2014 Operational Dynamics Consulting, Pty Ltd
+-- Copyright © 2012-2018 Operational Dynamics Consulting, Pty Ltd
 --
 -- The code in this file, and the program it is a part of, is
 -- made available to you by its authors as open source software:
@@ -14,7 +14,8 @@
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE MagicHash          #-}
 {-# LANGUAGE OverloadedStrings  #-}
-{-# OPTIONS -fno-warn-orphans  #-}
+{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_HADDOCK hide, not-home #-}
 
 module Network.Http.Inconvenience (
     URL,
@@ -217,13 +218,14 @@ establish u =
 -- @\"https:\/\/\"@ request using one of the convenience functions. It
 -- configures OpenSSL to use the default set of ciphers.
 --
--- On Linux systems, this function also configures OpenSSL to verify
--- certificates using the system certificates stored in @\/etc\/ssl\/certs@.
+-- On Linux, OpenBSD and FreeBSD systems, this function also configures
+-- OpenSSL to verify certificates using the system/distribution supplied
+-- certificate authorities' certificates
 --
 -- On other systems, /no certificate validation is performed/ by the
 -- generated 'SSLContext' because there is no canonical place to find
--- the set of system certificates. When using this library on a
--- non-Linux system, you are encouraged to install the system
+-- the set of system certificates. When using this library on such system,
+-- you are encouraged to install the system
 -- certificates somewhere and create your own 'SSLContext'.
 --
 {-
@@ -243,6 +245,9 @@ baselineContextSSL = withOpenSSL $ do
 #elif defined __FREEBSD__
     SSL.contextSetCAFile ctx "/usr/local/etc/ssl/cert.pem"
     SSL.contextSetVerificationMode ctx $ SSL.VerifyPeer True True Nothing
+#elif defined __OPENBSD__
+    SSL.contextSetCAFile ctx "/etc/ssl/cert.pem"
+    SSL.contextSetVerificationMode ctx $ SSL.VerifyPeer True True Nothing
 #else
     fedora <- doesDirectoryExist "/etc/pki/tls"
     if fedora
